summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/sqliteInt.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/sqliteInt.h')
-rw-r--r--kexi/3rdparty/kexisql3/src/sqliteInt.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kexi/3rdparty/kexisql3/src/sqliteInt.h b/kexi/3rdparty/kexisql3/src/sqliteInt.h
index 796653e7..74916805 100644
--- a/kexi/3rdparty/kexisql3/src/sqliteInt.h
+++ b/kexi/3rdparty/kexisql3/src/sqliteInt.h
@@ -104,22 +104,22 @@
/*
** If the following macro is set to 1, then NULL values are considered
** distinct when determining whether or not two entries are the same
-** in a UNIQUE index. This is the way PostgreSQL, Oracle, DB2, MySQL,
+** in a UNITQUE index. This is the way PostgreSQL, Oracle, DB2, MySQL,
** OCELOT, and Firebird all work. The SQL92 spec explicitly says this
** is the way things are suppose to work.
**
** If the following macro is set to 0, the NULLs are indistinct for
-** a UNIQUE index. In this mode, you can only have a single NULL entry
-** for a column declared UNIQUE. This is the way Informix and SQL Server
+** a UNITQUE index. In this mode, you can only have a single NULL entry
+** for a column declared UNITQUE. This is the way Informix and SQL Server
** work.
*/
-#define NULL_DISTINCT_FOR_UNIQUE 1
+#define NULL_DISTINCT_FOR_UNITQUE 1
/*
** The maximum number of attached databases. This must be at least 2
** in order to support the main database file (0) and the file used to
** hold temporary tables (1). And it must be less than 32 because
** we use a bitmask of databases with a u32 in places (for example
** the Parse.cookieMask field).
*/
#define MAX_ATTACHED 10
@@ -700,7 +700,7 @@ struct FKey {
** occurs. IGNORE means that the particular row that caused the constraint
** error is not inserted or updated. Processing continues and no error
** is returned. REPLACE means that preexisting database rows that caused
-** a UNIQUE constraint violation are removed so that the new insert or
+** a UNITQUE constraint violation are removed so that the new insert or
** update can proceed. Processing continues and no error is reported.
**
** RESTRICT, SETNULL, and CASCADE actions apply only to foreign keys.
@@ -779,7 +779,7 @@ struct Index {
Table *pTable; /* The SQL table being indexed */
int tnum; /* Page containing root of this index in database file */
u8 onError; /* OE_Abort, OE_Ignore, OE_Replace, or OE_None */
- u8 autoIndex; /* True if is automatically created (ex: by UNIQUE) */
+ u8 autoIndex; /* True if is automatically created (ex: by UNITQUE) */
u8 iDb; /* Index in sqlite.aDb[] of where this index is stored */
char *zColAff; /* String defining the affinity of each column */
Index *pNext; /* The next index associated with the same table */
@@ -976,9 +976,9 @@ struct IdList {
};
/*
** The bitmask datatype defined below is used for various optimizations.
*/
-typedef unsigned int Bitmask;
+typedef unsigned int Bittqmask;
/*
** The following structure describes the FROM clause of a SELECT statement.
@@ -1004,7 +1004,7 @@ struct SrcList {
i16 iCursor; /* The VDBE cursor number used to access this table */
Expr *pOn; /* The ON clause of a join */
IdList *pUsing; /* The USING clause of a join */
- Bitmask colUsed; /* Bit N (1<<N) set if column N or pTab is used */
+ Bittqmask colUsed; /* Bit N (1<<N) set if column N or pTab is used */
} a[1]; /* One entry for each identifier on the list */
};
@@ -1076,7 +1076,7 @@ struct WhereInfo {
** the context containing the match is incremented.
**
** Each subquery gets a new NameContext. The pNext field points to the
-** NameContext in the parent query. Thus the process of scanning the
+** NameContext in the tqparent query. Thus the process of scanning the
** NameContext list corresponds to searching through successively outer
** subqueries looking for a match.
*/
@@ -1176,7 +1176,7 @@ struct Parse {
int nMem; /* Number of memory cells used so far */
int nSet; /* Number of sets used so far */
u32 writeMask; /* Start a write transaction on these databases */
- u32 cookieMask; /* Bitmask of schema verified databases */
+ u32 cookieMask; /* Bittqmask of schema verified databases */
int cookieGoto; /* Address of OP_Goto to cookie verifier subroutine */
int cookieValue[MAX_ATTACHED+2]; /* Values of cookies to verify */
@@ -1328,9 +1328,9 @@ struct TriggerStep {
*
* struct TriggerStack has a "pNext" member, to allow linked lists to be
* constructed. When coding nested triggers (triggers fired by other triggers)
- * each nested trigger stores its parent trigger's TriggerStack as the "pNext"
+ * each nested trigger stores its tqparent trigger's TriggerStack as the "pNext"
* pointer. Once the nested trigger has been coded, the pNext value is restored
- * to the pTriggerStack member of the Parse stucture and coding of the parent
+ * to the pTriggerStack member of the Parse stucture and coding of the tqparent
* trigger continues.
*
* Before a nested trigger is coded, the linked list pointed to by the
@@ -104,22 +104,22 @@
** in order to support the main database file (0) and the file used to
** hold temporary tables (1). And it must be less than 32 because
-** we use a bitmask of databases with a u32 in places (for example
+** we use a bittqmask of databases with a u32 in places (for example
** the Parse.cookieMask field).
*/
@@ -976,9 +976,9 @@ struct IdList {
};
/*
-** The bitmask datatype defined below is used for various optimizations.
+** The bittqmask datatype defined below is used for various optimizations.
*/